@@ -97,8 +97,8 @@ bool notcurses_canutf8(const struct notcurses* nc);
 int notcurses_mouse_enable(struct notcurses* n);
 int notcurses_mouse_disable(struct notcurses* n);
 int ncplane_destroy(struct ncplane* ncp);
-int ncplane_mergedown(const struct ncplane* src, struct ncplane* dst, int begsrcy, int begsrcx, int leny, int lenx, int dsty, int dstx);
-int ncplane_mergedown_simple(const struct ncplane* restrict src, struct ncplane* restrict dst);
+int ncplane_mergedown(struct ncplane* src, struct ncplane* dst, int begsrcy, int begsrcx, int leny, int lenx, int dsty, int dstx);
+int ncplane_mergedown_simple(struct ncplane* restrict src, struct ncplane* restrict dst);
 void ncplane_erase(struct ncplane* n);
 int ncplane_cursor_move_yx(struct ncplane* n, int y, int x);
 void ncplane_cursor_yx(struct ncplane* n, int* y, int* x);
@@ -190,13 +190,13 @@ int nccell_load(struct ncplane* n, cell* c, const char* gcluster);
 int nccell_duplicate(struct ncplane* n, cell* targ, const cell* c);
 void nccell_release(struct ncplane* n, cell* c);
 const char* nccell_extended_gcluster(const struct ncplane* n, const cell* c);
-typedef struct palette256 {
+typedef struct ncpalette {
   // We store the RGB values as a regular ol' channel
   uint32_t chans[256];
-} palette256;
-palette256* palette256_new(struct notcurses* nc);
-int palette256_use(struct notcurses* nc, const palette256* p);
-void palette256_free(palette256* p);
+} ncpalette;
+ncpalette* ncpalette_new(struct notcurses* nc);
+int ncpalette_use(struct notcurses* nc, const ncpalette* p);
+void ncpalette_free(ncpalette* p);
 typedef enum {
   NCSCALE_NONE,
   NCSCALE_SCALE,
